@@ -4,6 +4,7 @@ from externals.moduleman.plugin import moduleman_plugin
 import subprocess
 import tempfile
 import pipes
+import os
 
 @moduleman_plugin
 class screenshot(BasePlugin):
@@ -16,7 +17,10 @@ class screenshot(BasePlugin):
 	return fuzzresult.code not in [404]
 
     def process(self, fuzzresult):
-	(fd, filename) = tempfile.mkstemp()
+        temp_name = next(tempfile._get_candidate_names())
+        defult_tmp_dir = tempfile._get_default_tempdir()
 
-	subprocess.call(['cutycapt', '--url=%s' % pipes.quote(fuzzresult.url), '--out=%s.png' % filename])
-	self.add_result("Screnshot taken, output at %s.png" % filename)
+        filename = os.path.join(defult_tmp_dir, temp_name + ".png")
+
+	subprocess.call(['cutycapt', '--url=%s' % pipes.quote(fuzzresult.url), '--out=%s' % filename])
+	self.add_result("Screnshot taken, output at %s" % filename)
